@@ -99,6 +99,11 @@ class CommonBrowserView(BrowserView):
         
         classes = []
         
+        if not hasattr(item, 'getURL'):
+            catalog = getToolByName(self.context, 'portal_catalog')
+            brains = catalog.queryCatalog({"UID": item.UID()})
+            item = brains[0]
+        
         for tag in item.Subject:
             classes.append("tag_%s"%tag)
         
@@ -156,6 +161,7 @@ class CommonBrowserView(BrowserView):
         if item.restrictedTraverse('@@plone').isStructuralFolder():
             catalog = getToolByName(self.context, 'portal_catalog')
             plone_utils = getToolByName(self.context, 'plone_utils')
+                
             path = '/'.join(item.getPhysicalPath())
             sm = getSecurityManager() 
             
@@ -687,6 +693,11 @@ class ImageAndFileView(CommonBrowserView):
         folder = aq_parent(aq_inner(self.context))
         return folder
 
+class CarouselItemView(CommonBrowserView):
+    """
+    View for items on the carousel.
+    """
+
 class MondayGroup(group.Group):
     label = u'Monday'
     fields = field.Fields(IWeekDayContent).select(
